@@ -76,7 +76,7 @@ def company(symbol, external=False, vprint=False, **query_params):
     :param symbol: The ticker or symbol of the stock you would like to request.
     :type symbol: string, required
     """
-    instance = iexCommon('stock', symbol, 'company', external=external).pre_execute()
+    instance = iexCommon('stock', symbol, 'company', external=external)
     return instance.execute()
     # url = replace_url_var(IEX_COMPANY_URL, symbol=symbol)
     # return get_iex_json_request(url, external=external, vprint=vprint)
